@@ -393,7 +393,7 @@ get_image (PolkitMateAuthenticationDialog *dialog)
 
   if (dialog->priv->icon_name == NULL || strlen (dialog->priv->icon_name) == 0)
     {
-      image = gtk_image_new_from_stock (GTK_STOCK_DIALOG_AUTHENTICATION, GTK_ICON_SIZE_DIALOG);
+      image = gtk_image_new_from_icon_name ("dialog-password", GTK_ICON_SIZE_DIALOG);
       goto out;
     }
 
@@ -405,7 +405,7 @@ get_image (PolkitMateAuthenticationDialog *dialog)
   if (vendor_pixbuf == NULL)
     {
       g_warning ("No icon for themed icon with name '%s'", dialog->priv->icon_name);
-      image = gtk_image_new_from_stock (GTK_STOCK_DIALOG_AUTHENTICATION, GTK_ICON_SIZE_DIALOG);
+      image = gtk_image_new_from_icon_name ("dialog-password", GTK_ICON_SIZE_DIALOG);
       goto out;
     }
 
@@ -519,7 +519,12 @@ add_row (GtkWidget *table, int row, const char *label_text, GtkWidget *entry)
 
   label = gtk_label_new_with_mnemonic (label_text);
   gtk_label_set_use_markup (GTK_LABEL (label), TRUE);
+#if GTK_CHECK_VERSION (3, 16, 0)
+  gtk_label_set_xalign (GTK_LABEL (label), 1.0);
+  gtk_label_set_yalign (GTK_LABEL (label), 0.5);
+#else
   gtk_misc_set_alignment (GTK_MISC (label), 1.0, 0.5);
+#endif
 
   gtk_table_attach (GTK_TABLE (table), label,
                     0, 1, row, row + 1,
@@ -659,15 +664,28 @@ polkit_mate_authentication_dialog_constructed (GObject *object)
   gtk_window_set_resizable (GTK_WINDOW (dialog), FALSE);
   gtk_window_set_icon_name (GTK_WINDOW (dialog), GTK_STOCK_DIALOG_AUTHENTICATION);
 
+#if GTK_CHECK_VERSION (3, 0, 0)
+  hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 12);
+#else
   hbox = gtk_hbox_new (FALSE, 12);
+#endif
   gtk_container_set_border_width (GTK_CONTAINER (hbox), 5);
   gtk_box_pack_start (GTK_BOX (content_area), hbox, TRUE, TRUE, 0);
 
   image = get_image (dialog);
+#if GTK_CHECK_VERSION (3, 0, 0)
+  gtk_widget_set_halign (image, GTK_ALIGN_CENTER);
+  gtk_widget_set_valign (image, GTK_ALIGN_START);
+#else
   gtk_misc_set_alignment (GTK_MISC (image), 0.5, 0.0);
+#endif
   gtk_box_pack_start (GTK_BOX (hbox), image, FALSE, FALSE, 0);
 
+#if GTK_CHECK_VERSION (3, 0, 0)
+  main_vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 10);
+#else
   main_vbox = gtk_vbox_new (FALSE, 10);
+#endif
   gtk_box_pack_start (GTK_BOX (hbox), main_vbox, TRUE, TRUE, 0);
 
   /* main message */
@@ -675,7 +693,12 @@ polkit_mate_authentication_dialog_constructed (GObject *object)
   s = g_strdup_printf ("<big><b>%s</b></big>", dialog->priv->message);
   gtk_label_set_markup (GTK_LABEL (label), s);
   g_free (s);
+#if GTK_CHECK_VERSION (3, 16, 0)
+  gtk_label_set_xalign (GTK_LABEL (label), 0.0);
+  gtk_label_set_yalign (GTK_LABEL (label), 0.5);
+#else
   gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
+#endif
   gtk_label_set_line_wrap (GTK_LABEL (label), TRUE);
 #if GTK_CHECK_VERSION (3, 0, 0)
   gtk_label_set_max_width_chars (GTK_LABEL (label), 50);
@@ -705,7 +728,12 @@ polkit_mate_authentication_dialog_constructed (GObject *object)
                                   "Authentication as the super user is required to perform this action."));
         }
     }
+#if GTK_CHECK_VERSION (3, 16, 0)
+  gtk_label_set_xalign (GTK_LABEL (label), 0.0);
+  gtk_label_set_yalign (GTK_LABEL (label), 0.5);
+#else
   gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
+#endif
   gtk_label_set_line_wrap (GTK_LABEL (label), TRUE);
 #if GTK_CHECK_VERSION (3, 0, 0)
   gtk_label_set_max_width_chars (GTK_LABEL (label), 50);
@@ -728,7 +756,11 @@ polkit_mate_authentication_dialog_constructed (GObject *object)
     }
 
   /* password entry */
+#if GTK_CHECK_VERSION (3, 0, 0)
+  vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
+#else
   vbox = gtk_vbox_new (FALSE, 0);
+#endif
   gtk_box_pack_start (GTK_BOX (main_vbox), vbox, FALSE, FALSE, 0);
 
   table_alignment = gtk_alignment_new (0.0, 0.0, 1.0, 1.0);
@@ -761,7 +793,11 @@ polkit_mate_authentication_dialog_constructed (GObject *object)
   gtk_expander_set_use_markup (GTK_EXPANDER (details_expander), TRUE);
   gtk_box_pack_start (GTK_BOX (content_area), details_expander, FALSE, FALSE, 0);
 
+#if GTK_CHECK_VERSION (3, 0, 0)
+  details_vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 10);
+#else
   details_vbox = gtk_vbox_new (FALSE, 10);
+#endif
   gtk_container_add (GTK_CONTAINER (details_expander), details_vbox);
 
   table_alignment = gtk_alignment_new (0.0, 0.0, 1.0, 1.0);
@@ -790,7 +826,12 @@ polkit_mate_authentication_dialog_constructed (GObject *object)
           s = g_strdup_printf ("<small>%s</small>", value);
           gtk_label_set_markup (GTK_LABEL (label), s);
           g_free (s);
-          gtk_misc_set_alignment (GTK_MISC (label), 0, 1.0);
+#if GTK_CHECK_VERSION (3, 16, 0)
+          gtk_label_set_xalign (GTK_LABEL (label), 0.0);
+          gtk_label_set_yalign (GTK_LABEL (label), 1.0);
+#else
+          gtk_misc_set_alignment (GTK_MISC (label), 0.0, 1.0);
+#endif
           s = g_strdup_printf ("<small><b>%s:</b></small>", key);
           add_row (table, rows, s, label);
           g_free (s);
@@ -809,7 +850,12 @@ polkit_mate_authentication_dialog_constructed (GObject *object)
                        dialog->priv->action_id);
   gtk_label_set_markup (GTK_LABEL (label), s);
   g_free (s);
-  gtk_misc_set_alignment (GTK_MISC (label), 0, 1.0);
+#if GTK_CHECK_VERSION (3, 16, 0)
+  gtk_label_set_xalign (GTK_LABEL (label), 0.0);
+  gtk_label_set_yalign (GTK_LABEL (label), 1.0);
+#else
+  gtk_misc_set_alignment (GTK_MISC (label), 0.0, 1.0);
+#endif
   add_row (table, rows++, _("<small><b>Action:</b></small>"), label);
   g_signal_connect (label, "activate-link", G_CALLBACK (action_id_activated), NULL);
 
@@ -826,7 +872,12 @@ polkit_mate_authentication_dialog_constructed (GObject *object)
                        dialog->priv->vendor);
   gtk_label_set_markup (GTK_LABEL (label), s);
   g_free (s);
-  gtk_misc_set_alignment (GTK_MISC (label), 0, 1.0);
+#if GTK_CHECK_VERSION (3, 16, 0)
+  gtk_label_set_xalign (GTK_LABEL (label), 0.0);
+  gtk_label_set_yalign (GTK_LABEL (label), 1.0);
+#else
+  gtk_misc_set_alignment (GTK_MISC (label), 0.0, 1.0);
+#endif
   add_row (table, rows++, _("<small><b>Vendor:</b></small>"), label);
 
   s = g_strdup_printf (_("Click to open %s"), dialog->priv->vendor_url);
